@@ -1,19 +1,22 @@
 """Scan dedicated for bliss format - based on EDF files"""
 
+from __future__ import annotations
+
+import pint
 import copy
 import io
 import json
 import logging
 import os
 import re
-from typing import Iterable, Optional, Union
+from typing import Iterable
+import warnings
 
 import fabio
 import numpy
 from lxml import etree
 from silx.io.url import DataUrl
 
-from pyunitsystem.metricsystem import MetricSystem
 
 from tomoscan.utils.io import deprecated, deprecated_warning
 from tomoscan.esrf.identifier.edfidentifier import EDFTomoScanIdentifier
@@ -24,24 +27,26 @@ from tomoscan.utils import docstring
 from .framereducer import EDFFrameReducer
 from .utils import extract_urls_from_edf, get_parameters_frm_par_or_info
 
+_ureg = pint.get_application_registry()
 _logger = logging.getLogger(__name__)
 
 
+__all__ = [
+    "EDFTomoScan",
+]
+
+
 class EDFTomoScan(TomoScanBase):
     """
     TomoScanBase instanciation for scan defined from .edf files
 
     :param scan: path to the root folder containing the scan.
-    :type scan: Union[str,None]
     :param dataset_basename: prefix of the dataset to handle
-    :type: Optional[str]
     :param scan_info: dictionary providing dataset information. Provided keys will overwrite information contained in .info.
                       Valid keys are: TODO
-    :type: Optional[dict]
     :param n_frames: Number of frames in each EDF file.
         If not provided, it will be inferred by reading the files.
         In this case, the frame number is guessed from the file name.
-    :type n_frames: Union[int, None]=None
     """
 
     _TYPE = "edf"
@@ -98,11 +103,11 @@ class EDFTomoScan(TomoScanBase):
 
     def __init__(
         self,
-        scan: Optional[str],
-        dataset_basename: Optional[str] = None,
-        scan_info: Optional[dict] = None,
-        n_frames: Optional[int] = None,
-        ignore_projections: Optional[Iterable] = None,
+        scan: str | None,
+        dataset_basename: str | None = None,
+        scan_info: dict | None = None,
+        n_frames: int | None = None,
+        ignore_projections: Iterable | None = None,
     ):
         TomoScanBase.__init__(
             self, scan=scan, type_=self._TYPE, ignore_projections=ignore_projections
@@ -120,21 +125,59 @@ class EDFTomoScan(TomoScanBase):
         self.__flat_on = None
         self.__scan_range = None
         self._edf_n_frames = n_frames
-        self.__distance = None
         self.__energy = None
-        self.__estimated_cor_frm_motor = None
         self._source = Source()
         """Source is not handle by EDFScan"""
         self._scan_info = None
         self.scan_info = scan_info
         self._dataset_basename = dataset_basename
+        self._ignore_init = False
+        # Used to handle ignored projections with EDF (done during reloading projections)
+        self._projs_indices_and_angles = None
+
+    def _rotation_angle(self):
+        """
+        Unofficial method for retrieving rotation angles.
+        Can't do better without proper metadata.
+        """
+        if self.scan_range is None:
+            raise ValueError("Need scan_range")
+        fullturn = abs(self.scan_range - 360) < abs(self.scan_range - 180)
+        angles = numpy.linspace(
+            0, self.scan_range, num=self.tomo_n, endpoint=fullturn, dtype="f"
+        )
+
+        return angles
+
+    def rotation_angle(self):
+        if self.ignore_projections is None:
+            return self._rotation_angle()
+        else:
+            all_indices, all_angles = self._projs_indices_and_angles
+            ignored_indices = self.get_ignored_projection_indices()
+            indices = sorted(list(set(all_indices) - set(ignored_indices)))
+            return all_angles[indices]
+
+    def _get_projs_indices_and_angles(self):
+        # Caching is important, as projections indices will change once the ignore mechanism is applied!
+        if self._projs_indices_and_angles is None:
+            if self._projections is None:
+                raise ValueError(
+                    "Need _reload_projections (or evaluate self.projections)"
+                )
+            projs_indices = sorted(self._projections.keys())
+            rot_angles = self._rotation_angle()  # heuristic, see above
+            self._projs_indices_and_angles = projs_indices, rot_angles
+        else:
+            projs_indices, rot_angles = self._projs_indices_and_angles
+        return projs_indices, rot_angles
 
     @property
-    def scan_info(self) -> Optional[dict]:
+    def scan_info(self) -> dict | None:
         return self._scan_info
 
     @scan_info.setter
-    def scan_info(self, scan_info: Optional[dict]) -> None:
+    def scan_info(self, scan_info: dict | None) -> None:
         if not isinstance(scan_info, (type(None), dict)):
             raise TypeError("scan info is expected to be None or an instance of dict")
         used_keys = (
@@ -175,15 +218,15 @@ class EDFTomoScan(TomoScanBase):
                     _logger.warning(f"{key} unrecognized. Valid keys are {valid_keys}")
         self._scan_info = scan_info
 
-    @docstring(TomoScanBase.clear_caches)
-    def clear_caches(self):
-        super().clear_caches()
+    @docstring(TomoScanBase.clear_cache)
+    def clear_cache(self):
+        super().clear_cache()
         self._projections = None
         self.__dim1 = None
         self.__dim2 = None
         self.__pixel_size = None
 
-    def clear_frames_caches(self):
+    def clear_frames_cache(self):
         self._darks = None
         self._flats = None
         self.__tomo_n = None
@@ -191,11 +234,11 @@ class EDFTomoScan(TomoScanBase):
         self.__dark_n = None
         self.__flat_on = None
         self.__scan_range = None
-        super().clear_frames_caches()
+        super().clear_frames_cache()
 
     @docstring(TomoScanBase.tomo_n)
     @property
-    def tomo_n(self) -> Union[None, int]:
+    def tomo_n(self) -> int | None:
         if self.__tomo_n is None:
             self.__tomo_n = EDFTomoScan.get_tomo_n(
                 scan=self.path,
@@ -206,7 +249,7 @@ class EDFTomoScan(TomoScanBase):
 
     @property
     @docstring(TomoScanBase.dark_n)
-    def dark_n(self) -> Union[None, int]:
+    def dark_n(self) -> int | None:
         if self.__dark_n is None:
             self.__dark_n = EDFTomoScan.get_dark_n(
                 scan=self.path,
@@ -217,7 +260,7 @@ class EDFTomoScan(TomoScanBase):
 
     @property
     @docstring(TomoScanBase.flat_n)
-    def flat_n(self) -> Union[None, int]:
+    def flat_n(self) -> int | None:
         if self.__flat_n is None:
             self.__flat_n = EDFTomoScan.get_ref_n(
                 scan=self.path,
@@ -228,11 +271,10 @@ class EDFTomoScan(TomoScanBase):
 
     @property
     @docstring(TomoScanBase.pixel_size)
-    def pixel_size(self) -> Union[None, int]:
+    def pixel_size(self) -> int | None:
         """
 
         :return: pixel size
-        :rtype: float
         """
         if self.__pixel_size is None:
             self.__pixel_size = EDFTomoScan._get_pixel_size(
@@ -243,18 +285,28 @@ class EDFTomoScan(TomoScanBase):
         return self.__pixel_size
 
     @property
-    def x_pixel_size(self) -> Optional[float]:
+    def sample_x_pixel_size(self) -> float | None:
         """For EDF only square pixel size is handled"""
         return self.pixel_size
 
     @property
-    def y_pixel_size(self) -> Optional[float]:
+    def sample_y_pixel_size(self) -> float | None:
         """For EDF only square pixel size is handled"""
         return self.pixel_size
 
+    @property
+    def detector_x_pixel_size(self) -> float | None:
+        # not provided by EDF at the moment
+        return None
+
+    @property
+    def detector_y_pixel_size(self) -> float | None:
+        # not provided by EDF at the moment
+        return None
+
     @property
     @deprecated(replacement="", since_version="1.1.0")
-    def x_real_pixel_size(self) -> Union[None, float]:
+    def x_real_pixel_size(self) -> float | None:
         if self.pixel_size is not None and self.magnification is not None:
             return self.pixel_size * self.magnification
         else:
@@ -262,7 +314,7 @@ class EDFTomoScan(TomoScanBase):
 
     @property
     @deprecated(replacement="", since_version="1.1.0")
-    def y_real_pixel_size(self) -> Union[None, float]:
+    def y_real_pixel_size(self) -> float | None:
         if self.pixel_size is not None and self.magnification is not None:
             return self.pixel_size * self.magnification
         else:
@@ -270,11 +322,10 @@ class EDFTomoScan(TomoScanBase):
 
     @property
     @docstring(TomoScanBase.dim_1)
-    def dim_1(self) -> Union[None, int]:
+    def dim_1(self) -> int | None:
         """
 
         :return: image dim1
-        :rtype: int
         """
         if self.__dim1 is None and self.path is not None:
             self.__dim1, self.__dim2 = EDFTomoScan.get_dim1_dim2(
@@ -286,11 +337,10 @@ class EDFTomoScan(TomoScanBase):
 
     @property
     @docstring(TomoScanBase.dim_2)
-    def dim_2(self) -> Union[None, int]:
+    def dim_2(self) -> int | None:
         """
 
         :return: image dim2
-        :rtype: int
         """
         if self.__dim2 is None and self.path is not None:
             self.__dim1, self.__dim2 = EDFTomoScan.get_dim1_dim2(
@@ -302,25 +352,25 @@ class EDFTomoScan(TomoScanBase):
 
     @property
     @docstring(TomoScanBase.x_translation)
-    def x_translation(self) -> Union[None, tuple]:
+    def x_translation(self) -> tuple | None:
         _logger.warning("x_translation Not supported for EDF")
         return None
 
     @property
     @docstring(TomoScanBase.y_translation)
-    def y_translation(self) -> Union[None, tuple]:
+    def y_translation(self) -> tuple | None:
         _logger.warning("y_translation Not supported for EDF")
         return None
 
     @property
     @docstring(TomoScanBase.z_translation)
-    def z_translation(self) -> Union[None, tuple]:
+    def z_translation(self) -> tuple | None:
         _logger.warning("z_translation Not supported for EDF")
         return None
 
     @property
     @docstring(TomoScanBase.ff_interval)
-    def ff_interval(self) -> Union[None, int]:
+    def ff_interval(self) -> int | None:
         if self.__flat_on is None and self.path is not None:
             self.__flat_on = EDFTomoScan.get_ff_interval(
                 scan=self.path,
@@ -331,7 +381,7 @@ class EDFTomoScan(TomoScanBase):
 
     @property
     @docstring(TomoScanBase.scan_range)
-    def scan_range(self) -> Union[None, int]:
+    def scan_range(self) -> int | None:
         if self.__scan_range is None and self.path is not None:
             self.__scan_range = EDFTomoScan.get_scan_range(
                 scan=self.path,
@@ -342,7 +392,7 @@ class EDFTomoScan(TomoScanBase):
 
     @property
     @docstring(TomoScanBase.flats)
-    def flats(self) -> Union[None, dict]:
+    def flats(self) -> dict | None:
         """
         flats are given as a dictionary with index as key and DataUrl as
         value"""
@@ -355,7 +405,7 @@ class EDFTomoScan(TomoScanBase):
 
     @property
     @docstring(TomoScanBase.projections)
-    def projections(self) -> Union[None, dict]:
+    def projections(self) -> dict | None:
         if self._projections is None and self.path is not None:
             self._reload_projections()
         return self._projections
@@ -370,7 +420,7 @@ class EDFTomoScan(TomoScanBase):
     @docstring(TomoScanBase.is_tomoscan_dir)
     @staticmethod
     def is_tomoscan_dir(
-        directory: str, dataset_basename: Optional[str] = None, **kwargs
+        directory: str, dataset_basename: str | None = None, **kwargs
     ) -> bool:
         return os.path.isfile(
             EDFTomoScan.get_info_file(
@@ -380,7 +430,7 @@ class EDFTomoScan(TomoScanBase):
 
     @staticmethod
     def get_info_file(
-        directory: str, dataset_basename: Optional[str] = None, **kwargs
+        directory: str, dataset_basename: str | None = None, **kwargs
     ) -> str:
         if dataset_basename is None:
             dataset_basename = os.path.basename(directory)
@@ -438,7 +488,7 @@ class EDFTomoScan(TomoScanBase):
             self._flats = EDFTomoScan.get_flats_url(self.path)
 
     @docstring(TomoScanBase.load_from_dict)
-    def load_from_dict(self, desc: Union[dict, io.TextIOWrapper]):
+    def load_from_dict(self, desc: dict | io.TextIOWrapper):
         if isinstance(desc, io.TextIOWrapper):
             data = json.load(desc)
         else:
@@ -453,8 +503,8 @@ class EDFTomoScan(TomoScanBase):
     @staticmethod
     def get_proj_urls(
         scan: str,
-        dataset_basename: Optional[str] = None,
-        n_frames: Union[int, None] = None,
+        dataset_basename: str | None = None,
+        n_frames: int | None = None,
     ) -> dict:
         """
         Return the dict of radios / projection for the given scan.
@@ -463,12 +513,9 @@ class EDFTomoScan(TomoScanBase):
         ending by .edf
 
         :param scan: is the path to the folder of acquisition
-        :type scan: str
         :param n_frames: Number of frames in each EDF file.
             If not provided, it is inferred by reading each file.
-        :type n_frames: int
         :return: dict of radios files with radio index as key and file as value
-        :rtype: dict
         """
         urls = dict({})
         if (scan is None) or not (os.path.isdir(scan)):
@@ -495,7 +542,7 @@ class EDFTomoScan(TomoScanBase):
 
     @staticmethod
     def is_a_proj_path(
-        fileName: str, scanID: str, dataset_basename: Optional[str] = None
+        fileName: str, scanID: str, dataset_basename: str | None = None
     ) -> bool:
         """Return True if the given fileName can fit to a Radio name"""
         fileBasename = os.path.basename(fileName)
@@ -519,7 +566,7 @@ class EDFTomoScan(TomoScanBase):
         return False
 
     @staticmethod
-    def guess_index_frm_file_name(_file: str, basename: str) -> Union[None, int]:
+    def guess_index_frm_file_name(_file: str, basename: str) -> int | None:
         """
         Guess the index of the file. Index is most of the an integer but can be
         a float for 'ref' for example if several are taken.
@@ -570,9 +617,9 @@ class EDFTomoScan(TomoScanBase):
     @staticmethod
     def get_tomo_n(
         scan: str,
-        dataset_basename: Optional[str] = None,
-        scan_info: Optional[dict] = None,
-    ) -> Union[None, int]:
+        dataset_basename: str | None = None,
+        scan_info: dict | None = None,
+    ) -> int | None:
         return EDFTomoScan.retrieve_information(
             scan=os.path.abspath(scan),
             dataset_basename=dataset_basename,
@@ -586,9 +633,9 @@ class EDFTomoScan(TomoScanBase):
     @staticmethod
     def get_dark_n(
         scan: str,
-        dataset_basename: Optional[str] = None,
-        scan_info: Optional[dict] = None,
-    ) -> Union[None, int]:
+        dataset_basename: str | None = None,
+        scan_info: dict | None = None,
+    ) -> int | None:
         return EDFTomoScan.retrieve_information(
             scan=os.path.abspath(scan),
             dataset_basename=dataset_basename,
@@ -604,9 +651,9 @@ class EDFTomoScan(TomoScanBase):
     @staticmethod
     def get_ref_n(
         scan: str,
-        dataset_basename: Optional[str] = None,
-        scan_info: Optional[dict] = None,
-    ) -> Union[None, int]:
+        dataset_basename: str | None = None,
+        scan_info: dict | None = None,
+    ) -> int | None:
         return EDFTomoScan.retrieve_information(
             scan=os.path.abspath(scan),
             dataset_basename=dataset_basename,
@@ -622,9 +669,9 @@ class EDFTomoScan(TomoScanBase):
     @staticmethod
     def get_ff_interval(
         scan: str,
-        dataset_basename: Optional[str] = None,
-        scan_info: Optional[dict] = None,
-    ) -> Union[None, int]:
+        dataset_basename: str | None = None,
+        scan_info: dict | None = None,
+    ) -> int | None:
         return EDFTomoScan.retrieve_information(
             scan=os.path.abspath(scan),
             dataset_basename=dataset_basename,
@@ -640,9 +687,9 @@ class EDFTomoScan(TomoScanBase):
     @staticmethod
     def get_scan_range(
         scan: str,
-        dataset_basename: Optional[str] = None,
-        scan_info: Optional[dict] = None,
-    ) -> Union[None, int]:
+        dataset_basename: str | None = None,
+        scan_info: dict | None = None,
+    ) -> int | None:
         return EDFTomoScan.retrieve_information(
             scan=os.path.abspath(scan),
             dataset_basename=dataset_basename,
@@ -658,9 +705,9 @@ class EDFTomoScan(TomoScanBase):
     @staticmethod
     def get_dim1_dim2(
         scan: str,
-        dataset_basename: Optional[str] = None,
-        scan_info: Optional[dict] = None,
-    ) -> Union[None, tuple]:
+        dataset_basename: str | None = None,
+        scan_info: dict | None = None,
+    ) -> tuple | None:
         d1 = EDFTomoScan.retrieve_information(
             scan=os.path.abspath(scan),
             dataset_basename=dataset_basename,
@@ -683,7 +730,7 @@ class EDFTomoScan(TomoScanBase):
 
     @property
     @docstring(TomoScanBase.instrument_name)
-    def instrument_name(self) -> Union[None, str]:
+    def instrument_name(self) -> str | None:
         """
 
         :return: instrument name
@@ -692,7 +739,7 @@ class EDFTomoScan(TomoScanBase):
 
     @property
     @docstring(TomoScanBase.title)
-    def title(self) -> Union[None, str]:
+    def title(self) -> str | None:
         """
 
         :return: title
@@ -701,7 +748,7 @@ class EDFTomoScan(TomoScanBase):
 
     @property
     @docstring(TomoScanBase.source_name)
-    def source_name(self) -> Union[None, str]:
+    def source_name(self) -> str | None:
         """
 
         :return: source name
@@ -710,7 +757,7 @@ class EDFTomoScan(TomoScanBase):
 
     @property
     @docstring(TomoScanBase.source_type)
-    def source_type(self) -> Union[None, str]:
+    def source_type(self) -> str | None:
         """
 
         :return: source type
@@ -718,10 +765,16 @@ class EDFTomoScan(TomoScanBase):
         return None
 
     @property
-    @docstring(TomoScanBase.distance)
-    def distance(self) -> Union[None, float]:
-        if self.__distance is None:
-            self.__distance = EDFTomoScan.retrieve_information(
+    def propagation_distance(self) -> float | None:
+        """Not handled by EDF"""
+        return None
+
+    @property
+    @docstring(TomoScanBase.sample_detector_distance)
+    def sample_detector_distance(self) -> float | None:
+        """sample / detector distance in meter"""
+        if self._sample_detector_distance is None:
+            self._sample_detector_distance = EDFTomoScan.retrieve_information(
                 self.path,
                 dataset_basename=self.dataset_basename,
                 ref_file=None,
@@ -730,10 +783,19 @@ class EDFTomoScan(TomoScanBase):
                 key_aliases=("distance",),
                 scan_info=self.scan_info,
             )
-        if self.__distance is None:
+        if self._sample_detector_distance is None:
             return None
         else:
-            return self.__distance * MetricSystem.MILLIMETER.value
+            return (
+                (self._sample_detector_distance * _ureg.millimeter)
+                .to(_ureg.meter)
+                .magnitude
+            )
+
+    @property
+    def source_sample_distance(self) -> float | None:
+        """Not handled for EDF"""
+        return None
 
     @property
     @docstring(TomoScanBase.field_of_view)
@@ -742,8 +804,8 @@ class EDFTomoScan(TomoScanBase):
         return None
 
     @property
-    @docstring(TomoScanBase.estimated_cor_frm_motor)
-    def estimated_cor_frm_motor(self):
+    @docstring(TomoScanBase.x_rotation_axis_pixel_position)
+    def x_rotation_axis_pixel_position(self):
         # not managed for EDF files
         return None
 
@@ -763,7 +825,7 @@ class EDFTomoScan(TomoScanBase):
         return self.__energy
 
     @property
-    def count_time(self) -> Union[list, None]:
+    def count_time(self) -> list | None:
         if self._count_time is None:
             count_time = EDFTomoScan.retrieve_information(
                 self.path,
@@ -783,10 +845,19 @@ class EDFTomoScan(TomoScanBase):
         return self._count_time
 
     @property
-    @docstring(TomoScanBase.electric_current)
     def electric_current(self) -> tuple:
-        if self._electric_current is None:
-            electric_current = EDFTomoScan.retrieve_information(
+        warnings.warn(
+            "electric_current is deprecated and will be removed in a future version. Use machine_current instead.",
+            DeprecationWarning,
+            stacklevel=2,
+        )
+        return self.machine_current
+
+    @property
+    @docstring(TomoScanBase.machine_current)
+    def machine_current(self) -> tuple:
+        if self._machine_current is None:
+            machine_current = EDFTomoScan.retrieve_information(
                 self.path,
                 dataset_basename=self.dataset_basename,
                 ref_file=None,
@@ -795,20 +866,20 @@ class EDFTomoScan(TomoScanBase):
                 key_aliases=("SRCUR", "machineCurrentStart"),
                 scan_info=self.scan_info,
             )
-            if electric_current is not None:
+            if machine_current is not None:
                 if self.tomo_n is not None:
-                    self._electric_current = [electric_current] * self.tomo_n
+                    self._machine_current = [machine_current] * self.tomo_n
                 else:
-                    self._electric_current = electric_current
+                    self._machine_current = machine_current
 
-        return self._electric_current
+        return self._machine_current
 
     @staticmethod
     def _get_pixel_size(
         scan: str,
-        dataset_basename: Optional[str] = None,
-        scan_info: Optional[dict] = None,
-    ) -> Union[None, float]:
+        dataset_basename: str | None = None,
+        scan_info: dict | None = None,
+    ) -> float | None:
         if os.path.isdir(scan) is False:
             return None
         value = EDFTomoScan.retrieve_information(
@@ -834,25 +905,22 @@ class EDFTomoScan(TomoScanBase):
         # for now pixel size are stored in microns.
         # We want to return them in meter
         if value is not None:
-            return value * MetricSystem.MICROMETER.value
+            return (value * _ureg.micrometer).to(_ureg.meter).magnitude
         else:
             return None
 
     @staticmethod
     def get_darks_url(
         scan_path: str,
-        dataset_basename: Optional[str] = None,
+        dataset_basename: str | None = None,
         prefix: str = "dark",
         file_ext: str = ".edf",
     ) -> dict:
         """
 
         :param scan_path:
-        :type scan_path: str
         :param prefix: flat file prefix
-        :type prefix: str
         :param file_ext: flat file extension
-        :type file_ext: str
         :return: list of flat frames as silx's `DataUrl`
         """
         res = {}
@@ -884,7 +952,7 @@ class EDFTomoScan(TomoScanBase):
     @staticmethod
     def get_flats_url(
         scan_path: str,
-        dataset_basename: Optional[str] = None,
+        dataset_basename: str | None = None,
         prefix: str = "refHST",
         file_ext: str = ".edf",
         ignore=None,
@@ -892,11 +960,8 @@ class EDFTomoScan(TomoScanBase):
         """
 
         :param scan_path:
-        :type scan_path: str
         :param prefix: flat frame file prefix
-        :type prefix: str
         :param file_ext: flat frame file extension
-        :type file_ext: str
         :return: list of refs as silx's `DataUrl`
         """
         res = {}
@@ -969,7 +1034,7 @@ class EDFTomoScan(TomoScanBase):
         return None
 
     @property
-    def detector_transformations(self) -> Optional[tuple]:
+    def detector_transformations(self) -> tuple | None:
         """
         not handled for EDF
         """
@@ -977,43 +1042,43 @@ class EDFTomoScan(TomoScanBase):
 
     def _reload_projections(self):
         if self.path is None:
-            return None
-        else:
-            all_projections = EDFTomoScan.get_proj_urls(
-                self.path,
-                n_frames=self._edf_n_frames,
-                dataset_basename=self.dataset_basename,
+            return
+        all_projections = EDFTomoScan.get_proj_urls(
+            self.path,
+            n_frames=self._edf_n_frames,
+            dataset_basename=self.dataset_basename,
+        )
+
+        def select_proj(ddict, from_, to_):
+            indexes = sorted(set(ddict.keys()))
+            sel_indexes = indexes[from_:to_]
+            res = {}
+            for index in sel_indexes:
+                res[index] = ddict[index]
+            return res
+
+        if self.tomo_n is not None and len(all_projections) > self.tomo_n:
+            self._projections = select_proj(all_projections, 0, self.tomo_n)
+            self._alignment_projections = select_proj(
+                all_projections, self.tomo_n, None
             )
-
-            def select_proj(ddict, from_, to_):
-                indexes = sorted(set(ddict.keys()))
-                sel_indexes = indexes[from_:to_]
-                res = {}
-                for index in sel_indexes:
-                    res[index] = ddict[index]
-                return res
-
-            if self.tomo_n is not None and len(all_projections) > self.tomo_n:
-                self._projections = select_proj(all_projections, 0, self.tomo_n)
-                self._alignment_projections = select_proj(
-                    all_projections, self.tomo_n, None
-                )
-            else:
-                self._projections = all_projections
-                self._alignment_projections = {}
-            if self.ignore_projections is not None:
-                for idx in self.ignore_projections:
-                    self._projections.pop(idx, None)
+        else:
+            self._projections = all_projections
+            self._alignment_projections = {}
+        if self._ignore_init is False:
+            for idx in self.get_ignored_projection_indices():
+                self._projections.pop(idx, None)
+            self._ignore_init = True
 
     @staticmethod
     def retrieve_information(
         scan: str,
-        dataset_basename: Optional[str],
-        ref_file: Union[str, None],
+        dataset_basename: str | None,
+        ref_file: str | None,
         key: str,
         type_: type,
-        key_aliases: Union[list, tuple, None] = None,
-        scan_info: Optional[dict] = None,
+        key_aliases: list | tuple | None = None,
+        scan_info: dict | None = None,
     ):
         """
         Try to retrieve information a .info file, an .xml or a flat field file.
@@ -1025,13 +1090,9 @@ class EDFTomoScan(TomoScanBase):
         :param ref_file: the refXXXX_YYYY which should contain information
                          about the scan. Ref in esrf reference is a flat.
         :param key: the key (information) we are looking for
-        :type key: str
-        :param type_: requestde out type if the information is found
-        :type type_: return type if the information is found.
+        :param type_: required out type if the information is found
         :param key_aliases: aliases of the key in the different file
-        :type key_aliases: list
         :param scan_info: dict containing keys that could overwrite .info file content
-        :type dict:
         :return: the requested information or None if not found
         """
         info_aliases = [key]
@@ -1039,11 +1100,11 @@ class EDFTomoScan(TomoScanBase):
             assert type(key_aliases) in (tuple, list)
             [info_aliases.append(alias) for alias in key_aliases]
 
+        # if user provided 'scan_info' then he might want ot overwrite the metadata value
         if scan_info is not None:
-            if key in scan_info:
-                return scan_info[key]
-            elif key.lower() in scan_info:
-                return scan_info[key.lower()]
+            info = scan_info.get(key, scan_info.get(key.lower(), None))
+            if info is not None:
+                return info
 
         if not os.path.isdir(scan):
             return None
@@ -1068,32 +1129,18 @@ class EDFTomoScan(TomoScanBase):
 
         # 2nd look for .info file
         def parseInfoFile(filePath):
-            def extractInformation(text, alias):
-                text = text.replace(alias, "")
-                text = text.replace("\n", "")
-                text = text.replace(" ", "")
-                text = text.replace("=", "")
-                return type_(text)
-
-            info = None
-            f = open(filePath, "r")
-            try:
-                line = f.readline()
-                while line:
-                    for alias in info_aliases:
-                        if alias in line:
-                            info = extractInformation(line, alias)
-                            break
-                    line = f.readline()
-            finally:
-                f.close()
-            return info
+            metadata = get_parameters_frm_par_or_info(filePath)
+            for alias in info_aliases:
+                if alias.lower() in metadata:
+                    return type_(metadata[alias.lower()])
+            return None
 
         if dataset_basename is None:
             dataset_basename = os.path.basename(scan)
         infoFiles = [os.path.join(scan, dataset_basename + ".info")]
         infoOnDataVisitor = infoFiles[0].replace("lbsram", "")
-        # hack to check in lbsram, would need to be removed to add some consistency
+        # Note: hack to check in /data/dataset instead of /lbsram/data.
+        # when data is saved to /lbsram with spec the dataset is saved in /lbsram/data/{dataset} and the .info in /data/{dataset}
         if os.path.isfile(infoOnDataVisitor):
             infoFiles.append(infoOnDataVisitor)
         for infoFile in infoFiles:
@@ -1157,7 +1204,7 @@ class EDFTomoScan(TomoScanBase):
     def get_energy_expected_location(self):
         return "::".join((self._get_info_file_path_short_name(), "Energy"))
 
-    def get_distance_expected_location(self):
+    def get_sample_detector_distance_expected_location(self):
         return "::".join((self._get_info_file_path_short_name(), "Distance"))
 
     def get_pixel_size_expected_location(self):
@@ -1176,9 +1223,7 @@ class EDFTomoScan(TomoScanBase):
         return f" edf scan({os.path.basename(os.path.abspath(self.path))})"
 
     @docstring(TomoScanBase.get_relative_file)
-    def get_relative_file(
-        self, file_name: str, with_dataset_prefix=True
-    ) -> Optional[str]:
+    def get_relative_file(self, file_name: str, with_dataset_prefix=True) -> str | None:
         if self.path is not None:
             if with_dataset_prefix:
                 basename = self.dataset_basename
@@ -1193,7 +1238,7 @@ class EDFTomoScan(TomoScanBase):
         return self.dataset_basename
 
     @property
-    def dataset_basename(self) -> Optional[str]:
+    def dataset_basename(self) -> str | None:
         if self._dataset_basename is not None:
             return self._dataset_basename
         elif self.path is None:
