@@ -1,37 +1,8 @@
 # coding: utf-8
-# /*##########################################################################
-# Copyright (C) 2016 European Synchrotron Radiation Facility
-#
-# Permission is hereby granted, free of charge, to any person obtaining a copy
-# of this software and associated documentation files (the "Software"), to deal
-# in the Software without restriction, including without limitation the rights
-# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
-# copies of the Software, and to permit persons to whom the Software is
-# furnished to do so, subject to the following conditions:
-#
-# The above copyright notice and this permission notice shall be included in
-# all copies or substantial portions of the Software.
-#
-# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
-# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
-# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
-# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
-# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
-# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
-# THE SOFTWARE.
-#
-#############################################################################
-"""
-Utils to mock scans
-"""
-
-__authors__ = ["H. Payno"]
-__license__ = "MIT"
-__date__ = "30/09/2019"
 
 import logging
 import os
-from xml.etree import cElementTree
+from xml.etree.cElementTree import Element, ElementTree  # nosec B405
 
 import fabio
 import fabio.edfimage
@@ -47,11 +18,14 @@ from .utils import dump_info_file
 
 _logger = logging.getLogger(__name__)
 
+__all__ = ["ScanMock", "MockNXtomo", "MockEDF", "MockHDF5"]
+
 
 class ScanMock:
     """Base class to mock as scan (radios, darks, flats, reconstructions...)"""
 
-    PIXEL_SIZE = 0.457
+    DETECTOR_PIXEL_SIZE = 0.457
+    SAMPLE_PIXEL_SIZE = 0.89
 
     def __init__(
         self,
@@ -83,12 +57,13 @@ class ScanMock:
         :param ref_n: repalced by flat_n
         :param flat_n:
         :param dark_n:
-        :param str scene: scene type.
+        :param scene: scene type.
                           * 'noise': generate radios from numpy.random
                           * `increase value`: first frame value will be0, then second 1...
                           * `arange`: arange through frames
                           * 'perfect-sphere: generate a sphere which just fit in the
                           detector dimensions
+
         TODO: add some differente scene type.
         """
         self.det_width = dim
@@ -208,18 +183,18 @@ class MockNXtomo(ScanMock):
         :param scan_path: directory of the file containing the hdf5 acquisition
         :param n_proj: number of projections (does not contain alignement proj)
         :param n_ini_proj: number of projection do add in the constructor
-        :param n_alignement_proj: number of alignment projection
-        :param int scan_range:
+        :param n_alignment_proj: number of alignment projection
+        :param scan_range:
         :param n_recons:
         :param n_pag_recons:
         :param recons_vol:
         :param dim: frame dim - only manage square fame for now
         :param create_ini_dark: create one initial dark frame on construction
-        :param create_ini_flat: create the initial serie of ref (n_ref) on
+        :param create_ini_flat: create the initial series of ref (n_ref) on
                                construction (after creation of the dark)
-        :param create_final_flat: create the final serie of ref (n_ref) on
+        :param create_final_flat: create the final series of ref (n_ref) on
                                construction (after creation of the dark)
-        :param n_refs: number of refs per serie
+        :param n_refs: number of refs per series
         :param distance: if not None then will save energy on the dataset
         :param energy: if not None then will save the distance on the dataset
         """
@@ -541,21 +516,24 @@ class MockNXtomo(ScanMock):
             entry_one = h5_file.require_group(self.scan_entry)
             instrument_grp = entry_one.require_group("instrument")
             detector_grp = instrument_grp.require_group("detector")
-            entry_one.require_group("sample")
+            sample_grp = entry_one.require_group("sample")
 
             entry_one.attrs["NX_class"] = "NXentry"
             entry_one.attrs["definition"] = "NXtomo"
             if "size" not in detector_grp:
                 detector_grp["size"] = (self.det_width, self.det_height)
             if "x_pixel_size" not in detector_grp:
-                detector_grp["x_pixel_size"] = ScanMock.PIXEL_SIZE
+                detector_grp["x_pixel_size"] = ScanMock.DETECTOR_PIXEL_SIZE
             if "y_pixel_size" not in detector_grp:
-                detector_grp["y_pixel_size"] = ScanMock.PIXEL_SIZE
+                detector_grp["y_pixel_size"] = ScanMock.DETECTOR_PIXEL_SIZE
             if "magnification" not in detector_grp and self._magnification is not None:
                 detector_grp["magnification"] = self._magnification
-            sample_grp = entry_one.require_group("sample")
             if "name" not in sample_grp:
                 sample_grp["name"] = self._sample_name
+            if "x_pixel_size" not in sample_grp:
+                sample_grp["x_pixel_size"] = ScanMock.SAMPLE_PIXEL_SIZE
+            if "y_pixel_size" not in sample_grp:
+                sample_grp["y_pixel_size"] = ScanMock.SAMPLE_PIXEL_SIZE
             if self._group_size is not None and "group_size" not in entry_one:
                 entry_one["group_size"] = self._group_size
 
@@ -563,15 +541,17 @@ class MockNXtomo(ScanMock):
         # no specific operation to do
         pass
 
-    def _define_fov(self, acquisition_fov, estimated_cor_from_motor):
+    def _define_fov(self, acquisition_fov, x_rotation_axis_pixel_position):
         with h5py.File(self.scan_master_file, "a") as h5_file:
             entry_one = h5_file.require_group(self.scan_entry)
             instrument_grp = entry_one.require_group("instrument")
             detector_grp = instrument_grp.require_group("detector")
             if "field_of_view" not in detector_grp:
                 detector_grp["field_of_view"] = acquisition_fov
-            if estimated_cor_from_motor is not None:
-                detector_grp["estimated_cor_from_motor"] = estimated_cor_from_motor
+            if x_rotation_axis_pixel_position is not None:
+                detector_grp["x_rotation_axis_pixel_position"] = (
+                    x_rotation_axis_pixel_position
+                )
 
     def add_energy(self, energy):
         with h5py.File(self.scan_master_file, "a") as h5_file:
@@ -627,7 +607,9 @@ class MockEDF(ScanMock):
     ):
         self._last_radio_index = -1
         self._energy = energy if energy is not None else self._ENERGY
-        self._pixel_size = pixel_size if pixel_size is not None else self.PIXEL_SIZE
+        self._pixel_size = (
+            pixel_size if pixel_size is not None else self.DETECTOR_PIXEL_SIZE
+        )
         self._distance = distance if distance is not None else self._DISTANCE
         super(MockEDF, self).__init__(
             scan_path=scan_path,
@@ -692,8 +674,8 @@ class MockEDF(ScanMock):
         )
         if not os.path.exists(xml_file):
             # write the final xml file
-            root = cElementTree.Element("root")
-            tree = cElementTree.ElementTree(root)
+            root = Element("root")
+            tree = ElementTree(root)
             tree.write(xml_file)
 
     def write_metadata(self, n_radio, scan_range, flat_n, dark_n):
@@ -790,7 +772,7 @@ class MockEDF(ScanMock):
         """
         create reconstruction files into the given folder
 
-        :param str folder: the path of the folder where to save the reconstruction
+        :param folder: the path of the folder where to save the reconstruction
         :param nRecons: the number of reconstruction to mock
         :param nPagRecons: the number of paganin reconstruction to mock
         :param volFile: true if we want to add a volFile with reconstruction
@@ -893,8 +875,8 @@ class MockEDF(ScanMock):
         xml_file = os.path.join(folder, basename + ".xml")
         if not os.path.exists(xml_file):
             # write the final xml file
-            root = cElementTree.Element("root")
-            tree = cElementTree.ElementTree(root)
+            root = Element("root")
+            tree = ElementTree(root)
             tree.write(xml_file)
 
     @staticmethod
@@ -918,23 +900,23 @@ class MockEDF(ScanMock):
         """
         Create some random radios and reconstruction in the folder
 
-        :param str scanID: the folder where to save the radios and scans
-        :param int nRadio: The number of radios to create
-        :param int nRecons: the number of reconstruction to mock
-        :param int nRecons: the number of paganin reconstruction to mock
-        :param int dim: dimension of the files (nb row/columns)
-        :param int scan_range: scan range, usually 180 or 360
-        :param int n_extra_radio: number of radio run after the full range is made
+        :param scanID: the folder where to save the radios and scans
+        :param nRadio: The number of radios to create
+        :param nRecons: the number of reconstruction to mock
+        :param nRecons: the number of paganin reconstruction to mock
+        :param dim: dimension of the files (nb row/columns)
+        :param scan_range: scan range, usually 180 or 360
+        :param n_extra_radio: number of radio run after the full range is made
                                   usually used to observe any sample movement
                                   during acquisition
-        :param bool start_dark: do we want to create dark serie at start
-        :param bool end_dark: do we want to create dark serie at end
-        :param bool start_flat: do we want to create flat serie at start
-        :param bool end_flat: do we want to create flat serie at end
-        :param start_dark_data: if start_dark set to True Optional value for the dark serie. Else will generate some random values
-        :param end_dark_data: if end_dark set to True Optional value for the dark serie. Else will generate some random values
-        :param start_flat_data: if start_flat set to True Optional value for the flat serie. Else will generate some random values
-        :param end_flat_data: if end_flat set to True Optional value for the flat serie. Else will generate some random values
+        :param start_dark: do we want to create dark series at start
+        :param end_dark: do we want to create dark series at end
+        :param start_flat: do we want to create flat series at start
+        :param end_flat: do we want to create flat series at end
+        :param start_dark_data: if start_dark set to True Optional value for the dark series. Else will generate some random values
+        :param end_dark_data: if end_dark set to True Optional value for the dark series. Else will generate some random values
+        :param start_flat_data: if start_flat set to True Optional value for the flat series. Else will generate some random values
+        :param end_flat_data: if end_flat set to True Optional value for the flat series. Else will generate some random values
         """
         assert type(scanID) is str
         assert type(nRadio) is int
@@ -953,15 +935,15 @@ class MockEDF(ScanMock):
         )
 
         if start_dark:
-            MockEDF.add_dark_serie(
+            MockEDF.add_dark_series(
                 scan_path=scanID, n_elmt=4, index=0, dim=dim, data=start_dark_data
             )
         if start_flat:
-            MockEDF.add_flat_serie(
+            MockEDF.add_flat_series(
                 scan_path=scanID, n_elmt=4, index=0, dim=dim, data=start_flat_data
             )
         if end_dark:
-            MockEDF.add_dark_serie(
+            MockEDF.add_dark_series(
                 scan_path=scanID,
                 n_elmt=4,
                 index=nRadio - 1,
@@ -969,7 +951,7 @@ class MockEDF(ScanMock):
                 data=end_dark_data,
             )
         if end_flat:
-            MockEDF.add_flat_serie(
+            MockEDF.add_flat_series(
                 scan_path=scanID,
                 n_elmt=4,
                 index=nRadio - 1,
@@ -980,7 +962,7 @@ class MockEDF(ScanMock):
         return Factory.create_scan_object(scanID)
 
     @staticmethod
-    def add_flat_serie(scan_path, n_elmt, index, dim, data):
+    def add_flat_series(scan_path, n_elmt, index, dim, data):
         ref_file = os.path.join(scan_path, f"ref0000_{index:04}.edf")
         if data is None:
             data = numpy.array(
@@ -993,7 +975,7 @@ class MockEDF(ScanMock):
         edf_writer.write(ref_file)
 
     @staticmethod
-    def add_dark_serie(scan_path, n_elmt, index, dim, data):
+    def add_dark_series(scan_path, n_elmt, index, dim, data):
         dark_file = os.path.join(scan_path, f"darkend{index:04}.edf")
         if data is None:
             data = numpy.array(
