@@ -1,5 +1,8 @@
 """module dedicated to esrf scans utils"""
 
+from __future__ import annotations
+
+
 import contextlib
 import fnmatch
 import logging
@@ -7,13 +10,16 @@ import os
 import sys
 import psutil
 import warnings
-from typing import Iterable, Union, Optional
+from typing import Iterable
 import resource
 import traceback
 
 import fabio
 import h5py
 import numpy
+
+from nxtomo.application.nxtomo import ImageKey
+
 from silx.io.dictdump import h5todict
 from silx.io.url import DataUrl
 from silx.io.utils import get_data as silx_get_data
@@ -21,18 +27,40 @@ from silx.io.utils import h5py_read_dataset
 from silx.utils.deprecation import deprecated
 from silx.io.utils import open as hdf5_open
 
+from tomoscan.utils.io import filter_esrf_mounting_points
 from tomoscan.scanbase import ReducedFramesInfos, TomoScanBase
 
 _logger = logging.getLogger(__name__)
 
 
+__all__ = [
+    "get_parameters_frm_par_or_info",
+    "extract_urls_from_edf",
+    "get_compacted_dataslices",
+    "from_sequences_to_grps",
+    "check_grp_is_valid",
+    "grp_is_complete",
+    "dataset_has_broken_vds",
+    "check_possible_issue_with_rlimit",
+    "get_datasets_linked_to_vds",
+    "get_unique_files_linked",
+    "get_files_from_pattern",
+    "dump_info_file",
+    "cwd_context",
+    "get_data",
+    "copy_h5_dict_darks_to",
+    "copy_h5_dict_flats_to",
+    "from_relative_reduced_frames_to_absolute",
+    "from_absolute_reduced_frames_to_relative",
+]
+
+
 def get_parameters_frm_par_or_info(file_: str) -> dict:
     """
     Create a dictionary from the file with the information name as keys and
     their values as values
 
     :param file_: path to the file to parse
-    :type file_: str
     :raises: ValueError when fail to parse some line.
     """
     assert os.path.exists(file_) and os.path.isfile(file_)
@@ -60,24 +88,21 @@ def get_parameters_frm_par_or_info(file_: str) -> dict:
             except Exception:
                 try:
                     value = float(value)
-                except Exception:
+                except ValueError:
                     pass
             ddict[key.lower()] = value
     return ddict
 
 
 def extract_urls_from_edf(
-    file_: str, start_index: Union[None, int], n_frames: Union[int, None] = None
+    file_: str, start_index: int | None, n_frames: int | None = None
 ) -> dict:
-    """
-    return one DataUrl for each frame contain in the file_
+    r"""
+    return one DataUrl for each frame contain in file\_
 
-    :param file_: path to the file to parse
-    :type file_: str
+    :param file\_: path to the file to parse
     :param n_frames: Number of frames in each edf file (inferred if not told)
-    :type n_frames: Union[int, None]
     :param start_index:
-    :type start_index: Union[None,start_index]
     """
     res = {}
     index = 0 if start_index is None else start_index
@@ -109,18 +134,16 @@ def get_compacted_dataslices(
     how to load the data: `{indices_set: data_location}`
     where `data_location` contains contiguous indices.
 
-    :param dict urls: Dictionary where the key is an integer and the value is
+    :param urls: Dictionary where the key is an integer and the value is
                       a silx `DataUrl`.
     :param max_grp_size: maximum size of url grps
-    :type max_grp_size: None or int
-    :param bool return_merged_indices: if True return the last merged indices.
+    :param return_merged_indices: if True return the last merged indices.
                                        Deprecated
-    :param bool return_url_set: return a set with url containing `urls` slices
+    :param return_url_set: return a set with url containing `urls` slices
                                 and data path
 
     :return: Dictionary where the key is a list of indices, and the value is
              the corresponding `silx.io.url.DataUrl` with merged data_slice
-    :rtype: dict
     """
 
     def _convert_to_slice(idx):
@@ -248,16 +271,16 @@ def from_sequences_to_grps(scans: Iterable) -> tuple:
 
 @deprecated(replacement="tomoscan.serie.check_serie_is_valid", since_version="0.8.0")
 def check_grp_is_valid(scans: Iterable):
-    from tomoscan.serie import check_serie_is_consistant_frm_sample_name
+    from tomoscan.serie import check_series_is_consistent_frm_sample_name
 
-    return check_serie_is_consistant_frm_sample_name(scans)
+    return check_series_is_consistent_frm_sample_name(scans)
 
 
 @deprecated(replacement="tomoscan.serie.serie_is_complete", since_version="0.8.0")
 def grp_is_complete(scans: Iterable) -> bool:
-    from tomoscan.serie import serie_is_complete_from_group_size
+    from tomoscan.serie import series_is_complete_from_group_size
 
-    return serie_is_complete_from_group_size(scans)
+    return series_is_complete_from_group_size(scans)
 
 
 def __get_log_fct(log_level):
@@ -286,8 +309,8 @@ def dataset_has_broken_vds(
 
 
     :param DataUrl url: url to the dataset to treat
-    :param bool raise_error: if True and dataset not existing will raise an error
-    :param bool return_unique_files: if True return unique files. As this step can be time consuming and reused it can sometimes be convenients
+    :param raise_error: if True and dataset not existing will raise an error
+    :param return_unique_files: if True return unique files. As this step can be time consuming and reused it can sometimes be convenients
     """
     if not isinstance(url, DataUrl):
         raise TypeError(f"{url} is expected to be an instance of {DataUrl}")
@@ -342,12 +365,12 @@ def dataset_has_broken_vds(
 
 
 def check_possible_issue_with_rlimit(
-    url: Optional[DataUrl],
+    url: DataUrl | None,
     raise_error=False,
     log_level=logging.WARNING,
     delta_n_file=0,
     substract_current_open=True,
-    unique_files: Optional[tuple] = None,
+    unique_files: tuple | None = None,
 ) -> bool:
     """
     check that the provided url does not contain more external file than (ulimit - delta_ulimit).
@@ -485,7 +508,6 @@ def get_unique_files_linked(url: DataUrl):
 def get_files_from_pattern(file_pattern: str, pattern: str, research_dir: str) -> dict:
     """
     return: all files using a {pattern} to store the index. Key is the index and value is the file name
-    :rtype: dict
     """
     files_frm_patterm = {}
     if ("{" + pattern + "}") not in file_pattern:
@@ -602,8 +624,8 @@ def copy_h5_dict_darks_to(
     """
     :param TomwerScanBase scan: target to copy darks
     :param DataUrl darks_url: DataUrl to find darks to be copied
-    :param bool save: should we save the darks to disk. If not will only be set on scan cache
-    :param bool raise_error_if_url_empty: if the provided DataUrl lead to now data shoudl we raise an error (like file or dataset missing...)
+    :param save: should we save the darks to disk. If not will only be set on scan cache
+    :param raise_error_if_url_empty: if the provided DataUrl lead to now data shoudl we raise an error (like file or dataset missing...)
     """
     from tomoscan.scanbase import TomoScanBase  # avoid cyclic import
 
@@ -646,8 +668,8 @@ def copy_h5_dict_flats_to(
     """
     :param TomwerScanBase scan: target to copy darks
     :param DataUrl darks_url: DataUrl to find darks to be copied
-    :param bool save: should we save the darks to disk. If not will only be set on scan cache
-    :param bool raise_error_if_url_empty: if the provided DataUrl lead to now data shoudl we raise an error (like file or dataset missing...)
+    :param save: should we save the darks to disk. If not will only be set on scan cache
+    :param raise_error_if_url_empty: if the provided DataUrl lead to now data shoudl we raise an error (like file or dataset missing...)
     """
     from tomoscan.scanbase import TomoScanBase  # avoid cyclic import
 
@@ -716,3 +738,99 @@ def from_absolute_reduced_frames_to_relative(reduced_frames: dict, scan: TomoSca
             return f"{int(index) / frame_n}r"
 
     return {convert(key): value for key, value in reduced_frames.items()}
+
+
+def get_n_series(image_key_values: tuple | list, image_key_type: ImageKey) -> int:
+    """
+    Return the number of series of an image_key. Image key can be dark, flat, or projection.
+    A series is defined as a contiguous elements in image_key_values
+
+    :param image_key_values: list or tuple of image_keys to consider. Can be integers or tomoscan.esrf.scan.hdf5scan.ImageKey
+    :param image_key_type: The kind of image key we want number of series for
+    """
+    image_key_type = ImageKey(image_key_type)
+    if image_key_type is ImageKey.INVALID:
+        raise ValueError(
+            "we can't count Invalid image keys series because those are ignored from tomoscan"
+        )
+    image_key_values = [ImageKey(img_key) for img_key in image_key_values]
+
+    # remove invalid frames
+    image_key_values = numpy.array(
+        image_key_values
+    )  # for filtering invalid value a numpy array is requested
+    image_key_values = image_key_values[image_key_values != ImageKey.INVALID]
+
+    n_series = 0
+    is_in_a_series = False
+    for frame in image_key_values:
+        if frame == image_key_type and not is_in_a_series:
+            is_in_a_series = True
+            n_series += 1
+        elif frame != image_key_type:
+            is_in_a_series = False
+    return n_series
+
+
+def get_series_slice(
+    image_key_values: tuple[int], image_key_type: ImageKey, series_index: int
+) -> slice | None:
+    """
+    return the DataUrl corresponding to the to the serie at `series_index` for the type of image_key_type.
+
+    Examples: with the following image_key_values:
+    (
+        ImageKey.DARK_FIELD
+        ImageKey.DARK_FIELD
+        ImageKey.FLAT_FIELD
+        ImageKey.FLAT_FIELD
+        ImageKey.FLAT_FIELD
+        ImageKey.PROJECTION
+        ImageKey.PROJECTION
+        ImageKey.PROJECTION
+        ImageKey.PROJECTION
+    )
+
+    .. code-block:: python
+
+        get_serie_url(image_key_values, ImageKey.FLAT_FIELD, serie_index=0) == slice(2, 5)
+        get_serie_url(image_key_values, ImageKey.FLAT_FIELD, serie_index=1) == None
+        get_serie_url(image_key_values, ImageKey.FLAT_FIELD, serie_index=-1) == slice(2, 5)
+    """
+    image_key_type = ImageKey(image_key_type)
+    if series_index == -1:
+        series_index = (
+            get_n_series(
+                image_key_values=image_key_values, image_key_type=image_key_type
+            )
+            - 1
+        )
+    n_series = -1
+    start = None
+    is_in_a_series = False
+    for i_frame, frame in enumerate(image_key_values):
+        frame = ImageKey(frame)
+        if frame.value == image_key_type.value and not is_in_a_series:
+            n_series += 1
+            is_in_a_series = True
+            if n_series == series_index:
+                start = i_frame
+        elif frame.value != image_key_type.value and is_in_a_series:
+            is_in_a_series = False
+            if n_series == series_index:
+                return slice(start, i_frame, 1)
+    if start is not None:
+        return slice(start, len(image_key_values), 1)
+    return None
+
+
+def from_bliss_original_file_to_raw(bliss_original_file: str | None) -> str | None:
+    """
+    convert NXtomo 'bliss_original_files' to drac raw parameter (folder containing the raw)
+    without some possible noise added by 'realpath' like '/mnt/multipath-shares' or '/gpfs/easy'
+    """
+    if bliss_original_file is None:
+        return None
+
+    bliss_original_file = filter_esrf_mounting_points(bliss_original_file)
+    return os.path.dirname(bliss_original_file)
