@@ -1,38 +1,10 @@
 # coding: utf-8
-# /*##########################################################################
-#
-# Copyright (c) 2016-2022 European Synchrotron Radiation Facility
-#
-# Permission is hereby granted, free of charge, to any person obtaining a copy
-# of this software and associated documentation files (the "Software"), to deal
-# in the Software without restriction, including without limitation the rights
-# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
-# copies of the Software, and to permit persons to whom the Software is
-# furnished to do so, subject to the following conditions:
-#
-# The above copyright notice and this permission notice shall be included in
-# all copies or substantial portions of the Software.
-#
-# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
-# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
-# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
-# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
-# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
-# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
-# THE SOFTWARE.
-#
-# ###########################################################################*/
 """module defining utils for an hdf5 volume"""
 
-
-__authors__ = ["H. Payno", "P. Paleo"]
-__license__ = "MIT"
-__date__ = "27/01/2022"
-
+from __future__ import annotations
 
 import logging
 import os
-from typing import Union, Optional
 
 import h5py
 import numpy
@@ -44,10 +16,12 @@ from tomoscan.utils.io import deprecated_warning
 from tomoscan.esrf.identifier.hdf5Identifier import HDF5VolumeIdentifier
 from tomoscan.scanbase import TomoScanBase
 from tomoscan.utils import docstring
-from tomoscan.volumebase import VolumeBase
+from tomoscan.volumebase import VolumeBase, SliceTuple
 
 _logger = logging.getLogger(__name__)
 
+__all__ = ["HDF5Volume", "get_default_data_path_for_volume"]
+
 
 class HDF5Volume(VolumeBase):
     """
@@ -59,13 +33,13 @@ class HDF5Volume(VolumeBase):
 
     def __init__(
         self,
-        file_path: Optional[str] = None,
-        data_path: Optional[str] = None,
-        data: Optional[numpy.ndarray] = None,
-        source_scan: Optional[TomoScanBase] = None,
-        metadata: Optional[dict] = None,
-        data_url: Optional[DataUrl] = None,
-        metadata_url: Optional[DataUrl] = None,
+        file_path: str | None = None,
+        data_path: str | None = None,
+        data: numpy.ndarray | None = None,
+        source_scan: TomoScanBase | None = None,
+        metadata: dict | None = None,
+        data_url: DataUrl | None = None,
+        metadata_url: DataUrl | None = None,
         overwrite: bool = False,
     ) -> None:
         url = self._get_url_from_file_path_data_path(
@@ -85,19 +59,23 @@ class HDF5Volume(VolumeBase):
         )
 
     @property
-    def data_extension(self):
+    def data_extension(self) -> None | str:
         if self.data_url is not None and self.data_url.file_path() is not None:
-            return os.path.splitext(self.data_url.file_path())[1]
+            _, extension = os.path.splitext(self.data_url.file_path())
+            if extension:
+                return extension[1:]
 
     @property
-    def metadata_extension(self):
+    def metadata_extension(self) -> None | str:
         if self.metadata_url is not None and self.metadata_url.file_path() is not None:
-            return os.path.splitext(self.metadata_url.file_path())[1]
+            _, extension = os.path.splitext(self.metadata_url.file_path())
+            if extension:
+                return extension[1:]
 
     @staticmethod
     def _get_url_from_file_path_data_path(
-        file_path: Optional[str], data_path: Optional[str]
-    ) -> Optional[DataUrl]:
+        file_path: str | None, data_path: str | None
+    ) -> DataUrl | None:
         if file_path is not None and data_path is not None:
             return DataUrl(file_path=file_path, data_path=data_path, scheme="silx")
         else:
@@ -118,7 +96,7 @@ class HDF5Volume(VolumeBase):
         return self._file_path
 
     @file_path.setter
-    def file_path(self, file_path: Optional[str]):
+    def file_path(self, file_path: str | None):
         if not (file_path is None or isinstance(file_path, str)):
             raise TypeError
         self._file_path = file_path
@@ -131,7 +109,7 @@ class HDF5Volume(VolumeBase):
         return self._data_path
 
     @data_path.setter
-    def data_path(self, data_path: Optional[str]):
+    def data_path(self, data_path: str | None):
         if not (data_path is None or isinstance(data_path, str)):
             raise TypeError
         self._data_path = data_path
@@ -140,7 +118,7 @@ class HDF5Volume(VolumeBase):
         )
 
     @docstring(VolumeBase)
-    def deduce_data_and_metadata_urls(self, url: Optional[DataUrl]) -> tuple:
+    def deduce_data_and_metadata_urls(self, url: DataUrl | None) -> tuple:
         if url is None:
             return None, None
         else:
@@ -169,7 +147,7 @@ class HDF5Volume(VolumeBase):
             )
 
     @docstring(VolumeBase)
-    def save_data(self, url: Optional[DataUrl] = None, mode="a", **kwargs) -> None:
+    def save_data(self, url: DataUrl | None = None, mode="a", **kwargs) -> None:
         """
         :raises KeyError: if data path already exists and overwrite set to False
         :raises ValueError: if data is None
@@ -280,7 +258,7 @@ class HDF5Volume(VolumeBase):
                 )
 
     @docstring(VolumeBase)
-    def save_metadata(self, url: Optional[DataUrl] = None) -> None:
+    def save_metadata(self, url: DataUrl | None = None) -> None:
         """
         :raises KeyError: if data path already exists and overwrite set to False
         :raises ValueError: if data is None
@@ -308,7 +286,7 @@ class HDF5Volume(VolumeBase):
 
     @docstring(VolumeBase)
     def load_data(
-        self, url: Optional[DataUrl] = None, store: bool = True
+        self, url: DataUrl | None = None, store: bool = True
     ) -> numpy.ndarray:
         url = url or self.data_url
         if url is None:
@@ -329,12 +307,12 @@ class HDF5Volume(VolumeBase):
 
     def get_slice(
         self,
-        index: Union[int, str] = None,
+        index: int | str = None,
         axis=None,
         xy=None,
         xz=None,
         yz=None,
-        url: Optional[DataUrl] = None,
+        url: DataUrl | None = None,
     ):
         if xy is yz is xz is None and (index is None or axis is None):
             raise ValueError("index and axis should be provided")
@@ -398,8 +376,19 @@ class HDF5Volume(VolumeBase):
                 else:
                     raise KeyError(f"Data path {url.data_path()} not found.")
 
+    def _get_slices_from_disk(
+        self, slices: tuple[SliceTuple], url: DataUrl | None = None
+    ) -> dict[SliceTuple, numpy.ndarray]:
+        """
+        read from files a couple of slices along any axis.
+        """
+        url = url or self.data_url
+        with open_hdf5(filename=url.file_path()) as h5s:
+            if url.data_path() in h5s:
+                return self.select_slices(volume=h5s[url.data_path()], slices=slices)
+
     @docstring(VolumeBase)
-    def load_metadata(self, url: Optional[DataUrl] = None, store: bool = True) -> dict:
+    def load_metadata(self, url: DataUrl | None = None, store: bool = True) -> dict:
         url = url or self.metadata_url
         if url is None:
             raise ValueError(
