@@ -1,39 +1,12 @@
 # coding: utf-8
-# /*##########################################################################
-#
-# Copyright (c) 2016-2022 European Synchrotron Radiation Facility
-#
-# Permission is hereby granted, free of charge, to any person obtaining a copy
-# of this software and associated documentation files (the "Software"), to deal
-# in the Software without restriction, including without limitation the rights
-# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
-# copies of the Software, and to permit persons to whom the Software is
-# furnished to do so, subject to the following conditions:
-#
-# The above copyright notice and this permission notice shall be included in
-# all copies or substantial portions of the Software.
-#
-# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
-# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
-# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
-# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
-# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
-# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
-# THE SOFTWARE.
-#
-# ###########################################################################*/
 """module defining utils for a jp2k volume"""
+from __future__ import annotations
 
-
-__authors__ = ["H. Payno", "P. Paleo"]
-__license__ = "MIT"
-__date__ = "27/01/2022"
-
+from __future__ import annotations
 
 import logging
 import os
 import re
-from typing import Optional
 
 import numpy
 from silx.io.dictdump import dicttoini
@@ -42,16 +15,19 @@ from silx.io.url import DataUrl
 
 from tomoscan.scanbase import TomoScanBase
 from tomoscan.utils import docstring
-from tomoscan.volumebase import VolumeBase
+from tomoscan.volumebase import VolumeBase, SliceTuple
 
 _logger = logging.getLogger(__name__)
 
 
+__all__ = ["VolumeSingleFrameBase", "TIFFLikeDiskAccessor"]
+
+
 class VolumeSingleFrameBase(VolumeBase):
     """
     Base class for Volume where each slice is saved in a separate file like edf, jp2k or tiff.
 
-    :param int start_index: users can provide a shift on fill name when saving the file. This is interesting if you want to create
+    :param start_index: users can provide a shift on fill name when saving the file. This is interesting if you want to create
                         create a volume from several writer.
     """
 
@@ -68,15 +44,15 @@ class VolumeSingleFrameBase(VolumeBase):
 
     def __init__(
         self,
-        url: Optional[DataUrl] = None,
-        data: Optional[numpy.ndarray] = None,
-        source_scan: Optional[TomoScanBase] = None,
-        metadata: Optional[dict] = None,
-        data_url: Optional[DataUrl] = None,
-        metadata_url: Optional[DataUrl] = None,
+        url: DataUrl | None = None,
+        data: numpy.ndarray | None = None,
+        source_scan: TomoScanBase | None = None,
+        metadata: dict | None = None,
+        data_url: DataUrl | None = None,
+        metadata_url: DataUrl | None = None,
         overwrite: bool = False,
         start_index: int = 0,
-        volume_basename: Optional[str] = None,
+        volume_basename: str | None = None,
         data_extension=None,
         metadata_extension="txt",
     ) -> None:
@@ -92,13 +68,32 @@ class VolumeSingleFrameBase(VolumeBase):
             data_extension,
             metadata_extension,
         )
-
         self._start_index = start_index
+        self._skip_existing_data_files_removal = False
+
+    def get_first_file(self):
+        try:
+            first_file = next(self.browse_data_files())
+        except StopIteration:
+            first_file = None
+        return first_file
+
+    def get_file_slice_index(self, filename):
+        if (
+            self.DEFAULT_DATA_PATH_PATTERN
+            != VolumeSingleFrameBase.DEFAULT_DATA_PATH_PATTERN
+        ):
+            raise ValueError("Non-default file name pattern not handled")
+        return int(filename.split(".")[0].split("_")[-1])
 
     @property
     def start_index(self) -> int:
         return self._start_index
 
+    @start_index.setter
+    def start_index(self, start_idx: int) -> None:
+        self._start_index = start_idx
+
     def get_volume_basename(self, url=None):
         if self._volume_basename is not None:
             return self._volume_basename
@@ -106,8 +101,25 @@ class VolumeSingleFrameBase(VolumeBase):
             url = url or self.data_url
             return os.path.basename(url.file_path())
 
+    @property
+    def skip_existing_data_files_removal(self) -> bool:
+        """The loading of the volume for single frame base is done by loading all the file
+        contained in a folder data_url.file_path(). When saving the data we make sure there is no 'remaining' of
+        any previous saving by using the file pattern.
+        But when we want to save a volume from several thread (one thread save the n first frame, second the n next frame ...) this
+        could be a limitation.
+        So in this case we can use the 'ignore_existing_files' that will avoid calling '_remove_existing_data_files'
+        """
+        return self._skip_existing_data_files_removal
+
+    @skip_existing_data_files_removal.setter
+    def skip_existing_data_files_removal(self, ignore: bool) -> None:
+        if not isinstance(ignore, bool):
+            raise TypeError(f"ignore should be a bool. Got {type(ignore)}")
+        self._skip_existing_data_files_removal = ignore
+
     @docstring(VolumeBase)
-    def deduce_data_and_metadata_urls(self, url: Optional[DataUrl]) -> tuple:
+    def deduce_data_and_metadata_urls(self, url: DataUrl | None) -> tuple:
         """
         Deduce automatically data and metadata url.
         Default data will be saved as single frame edf.
@@ -141,7 +153,7 @@ class VolumeSingleFrameBase(VolumeBase):
             )
 
     @docstring(VolumeBase)
-    def load_metadata(self, url: Optional[DataUrl] = None, store: bool = True) -> dict:
+    def load_metadata(self, url: DataUrl | None = None, store: bool = True) -> dict:
         url = url or self.metadata_url
         if url is None:
             raise ValueError(
@@ -172,7 +184,7 @@ class VolumeSingleFrameBase(VolumeBase):
         return metadata
 
     @docstring(VolumeBase)
-    def save_metadata(self, url: Optional[DataUrl] = None) -> None:
+    def save_metadata(self, url: DataUrl | None = None) -> None:
         if self.metadata is None:
             raise ValueError("No data to be saved")
         url = url or self.metadata_url
@@ -222,8 +234,35 @@ class VolumeSingleFrameBase(VolumeBase):
         }
         return data_path.format(**keywords)
 
+    def remove_existing_data_files(self, url: DataUrl | None = None) -> None:
+        """Clean any existing files (if overwrite and rights) that must be used for saving"""
+        url = url or self.data_url
+        if not os.path.exists(url.file_path()):
+            return
+
+        research_pattern = self.get_data_path_pattern_for_data(
+            data_path=url.data_path(),
+            volume_basename=self.get_volume_basename(url=url),
+        )
+        try:
+            research_pattern = re.compile(research_pattern)
+        except Exception:
+            _logger.error(
+                f"Fail to compute regular expression for {research_pattern}. Unable to load data"
+            )
+            return None
+        for file_ in sorted(os.listdir(url.file_path())):
+            if research_pattern.match(file_):
+                full_file_path = os.path.join(url.file_path(), file_)
+                if self.overwrite:
+                    os.remove(full_file_path)
+                else:
+                    raise OSError(
+                        f"Output file '{full_file_path}' already exists. No overwrite required. Skip writting"
+                    )
+
     @docstring(VolumeBase)
-    def save_data(self, url: Optional[DataUrl] = None) -> None:
+    def save_data(self, url: DataUrl | None = None) -> None:
         if self.data is None:
             raise ValueError("No data to be saved")
         url = url or self.data_url
@@ -232,6 +271,9 @@ class VolumeSingleFrameBase(VolumeBase):
                 "Cannot get data_url. An url should be provided. Don't know where to save this."
             )
         else:
+            if not self.skip_existing_data_files_removal:
+                self.remove_existing_data_files(url=url)
+
             _logger.info(f"save data to {url.path()}")
             # if necessary create output directory (some third part writer does not do it for us)
             try:
@@ -302,7 +344,7 @@ class VolumeSingleFrameBase(VolumeBase):
 
     @docstring(VolumeBase)
     def load_data(
-        self, url: Optional[DataUrl] = None, store: bool = True
+        self, url: DataUrl | None = None, store: bool = True
     ) -> numpy.ndarray:
         url = url or self.data_url
         if url is None:
@@ -330,18 +372,18 @@ class VolumeSingleFrameBase(VolumeBase):
         """
         Function dedicated for volune saving each frame on a single file
 
-        :param numpy.ndarray frame: frame to be save
-        :param str file_name: path to store the data
-        :param str scheme: scheme to save the data
+        :param frame: frame to be save
+        :param file_name: path to store the data
+        :param scheme: scheme to save the data
         """
         raise NotImplementedError("Base class")
 
     def load_frame(self, file_name: str, scheme: str) -> numpy.ndarray:
         """
-        Function dedicated for volune saving each frame on a single file
+        Function dedicated for volume saving each frame on a single file
 
-        :param str file_name: path to store the data
-        :param str scheme: scheme to save the data
+        :param file_name: path to store the data
+        :param scheme: scheme to save the data
         """
         raise NotImplementedError("Base class")
 
@@ -372,7 +414,7 @@ class VolumeSingleFrameBase(VolumeBase):
             research_pattern = re.compile(research_pattern)
         except Exception:
             _logger.error(
-                f"Fail to compute regular expresion for {research_pattern}. Unable to load data"
+                f"Fail to compute regular expression for {research_pattern}. Unable to load data"
             )
             return None
 
@@ -405,8 +447,107 @@ class VolumeSingleFrameBase(VolumeBase):
             url = url or self.data_url
             if url is None:
                 raise ValueError(
-                    "No data and data_url know and no url provided. Uanble to browse slices"
+                    "No data and data_url know and no url provided. Unable to browse slices"
                 )
 
             for file_path in self.browse_data_files(url=url):
                 yield self.load_frame(file_name=file_path, scheme=url.scheme())
+
+
+class TIFFLikeDiskAccessor:
+    """
+    Class to define a common implementation of '_get_slices_from_disk' for 'tiff like' format (!!! single frame per file !!!).
+    (format unable to implement 'read_n_lines_in_file', 'read_n_columns_in_file' and 'read_file' functions
+
+    .. warning:: a class that want to inherit from TIFFLikeDiskAccessor should also inherit from VolumeSingleFrameBase.
+        a separated class has been created instead of a direct inheritance to clearly separate the '_get_slices_from_disk' instantiation
+    """
+
+    def _get_slices_from_disk(
+        self, slices: tuple[SliceTuple], url: DataUrl | None = None
+    ) -> dict[SliceTuple, numpy.ndarray]:
+
+        _logger.debug("Try to read %s from disk", slices)
+        volume_shape = self.get_volume_shape()  # pylint: disable=E1101
+        _logger.debug("volume shape is %s", volume_shape)
+
+        def get_output_slice_shape(axis):
+            if axis == 0:
+                return (volume_shape[1], volume_shape[2])
+            elif axis == 1:
+                return (volume_shape[0], volume_shape[2])
+            elif axis == 2:
+                return (volume_shape[0], volume_shape[1])
+            else:
+                raise ValueError(f"unknown requested axis ({axis})")
+
+        # init resulting data
+        result = {
+            slice_: numpy.empty(shape=get_output_slice_shape(slice_.axis))
+            for slice_ in slices
+        }
+        _logger.debug(
+            "Reserve numpy arrays for reading %s",
+            {slice_: (data.shape, data.dtype) for (slice_, data) in result.items()},
+        )
+        from tomoscan.esrf.volume.utils import (
+            group_slices_by_axis,
+        )  # avoid cyclic import
+
+        indices_to_read_per_axis: dict[int, set[int]] = group_slices_by_axis(
+            slices=slices, volume_shape=volume_shape
+        )
+        _logger.debug("slices ordered by axis %s", indices_to_read_per_axis)
+
+        for i_axis_0, file_name in enumerate(
+            self.browse_data_files()  # pylint: disable=E1101
+        ):
+            # browse all files. Each file represent a slice along the axis 0
+            data_cache = None
+            # used to cache data in the case a full slice
+            # needs to be read along axis 0. Then we can reuse it for over axis
+
+            # handle axis 0
+            if i_axis_0 in indices_to_read_per_axis[0]:
+                data_cache = self.read_file(file_name=file_name)
+                result[(0, i_axis_0)][:] = data_cache
+                indices_to_read_per_axis[0].remove(i_axis_0)
+
+            # test: if all slices are read avoid going through all the slices
+            if numpy.sum([len(indices_to_read_per_axis[i]) for i in range(3)]) == 0:
+                break
+
+            # if data has been read already let's benefit from it
+            if data_cache is not None:
+                for index in indices_to_read_per_axis[1]:
+                    result[(1, index)][i_axis_0:] = data_cache[index, :]
+                for index in indices_to_read_per_axis[2]:
+                    result[(2, index)][i_axis_0, :] = data_cache[:, index]
+            else:
+                # else read lines and / or columns directly
+                if len(indices_to_read_per_axis[1]) > 0:
+                    data = self.read_n_columns_in_file(
+                        file_name=file_name, column_indices=indices_to_read_per_axis[1]
+                    )
+                    assert len(data) == len(indices_to_read_per_axis[1])
+                    for column, index in zip(data, indices_to_read_per_axis[1]):
+                        result[(1, index)][i_axis_0, :] = column
+
+                if len(indices_to_read_per_axis[2]) > 0:
+                    data = self.read_n_lines_in_file(
+                        file_name=file_name, line_indices=indices_to_read_per_axis[2]
+                    )
+                    assert len(data) == len(indices_to_read_per_axis[2])
+                    for line, index in zip(data, indices_to_read_per_axis[2]):
+                        result[(2, index)][i_axis_0, :] = line
+
+        return result
+
+    def read_n_lines_in_file(self, file_name, line_indices) -> tuple:
+        raise NotImplementedError("Base class")
+
+    def read_n_columns_in_file(self, file_name, column_indices) -> tuple:
+        raise NotImplementedError("Base class")
+
+    def read_file(self, file_name) -> tuple:
+        raise NotImplementedError("Base class")
